@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 BEGIN {
-	our $VERSION = '0.1.9'; # VERSION
+	our $VERSION = '0.2.0'; # VERSION
 }
 use Moose;
 with (
@@ -58,9 +58,14 @@ sub munge_file {
 		}
 	}
 
-	unless ( $munged_version ) {
-		my $fn = $file->name;
-		$self->log( "Skipping $fn" . ': has no "# VERSION" comment' );
+	if ( $munged_version ) {
+		$self->log_debug([ 'adding $VERSION assignment to %s', $file->name ]);
+	}
+	else {
+		$self->log( 'Skipping: "'
+			. $file->name
+			. '" has no "# VERSION" comment'
+			);
 	}
 	return;
 }
@@ -78,7 +83,7 @@ Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version
 
 =head1 VERSION
 
-version 0.1.9
+version 0.2.0
 
 =head1 SYNOPSIS
 
